%define fversion %(echo %version | tr -d .)
%define dversion %(echo %version | sed s/\\\\./_/)

Name:           zsnes
Epoch:          1
Version:        1.51
Release:        %mkrel 15
Summary:        Nintendo Super NES / Super Famicom Emulator
Group:          Emulators
License:        GPLv2+
URL:            https://zsnes.sourceforge.net/
Source0:        https://downloads.sourceforge.net/zsnes/%{name}%{fversion}src.tar.bz2
Source1:        %{name}-icons.tar.bz2
Patch0:         zsnes150-desktop.patch
Patch1:         zsnes-1.51-libao.patch
Patch2:         zsnes-1.51-gcc43.patch
Patch3:         zsnes-1.51-libpng15.patch
Patch4:         zsnes-1.51-gcc4.7.patch
Patch5:         zsnes-1.51-hat-events.patch
Patch6:         zsnes-1.51-matrix-init.patch
Patch7:         zsnes-1.51-no-strip.patch
Patch8:         zsnes-1.51-gcc10.patch

BuildRequires:  nasm
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(zlib)
# Does not build currently on x86_64
ExclusiveArch:  %ix86

%description
This is an emulator for Nintendo's 16 bit console, called Super Nintendo
Entertainment System or Super Famicom. It features a pretty accurate emulation
of that system's graphic and sound capabilities.
The GUI enables the user to select games, change options, enable cheat codes
and to save the game state, even network play is possible.

%prep
%setup -q -a1 -n %{name}_%{dversion}
%patch0 -p1
%patch1 -p1
%patch2 -p0
%patch3 -p0
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

# Use -std=gnu++14 for CXX source for now, this is not ready for C++17
sed -i src/configure.in -e '\@CXXFLAGS=@s|CFLAGS|CFLAGS -std=gnu++14 |'

%build
pushd src
autoreconf -fiv
# zsnes do not work with fortify patch, and i frankly do not want to mess with the mix of asm and C source code
# (misc)
export CFLAGS="-O2 -g -pipe -fexceptions -fomit-frame-pointer -fasynchronous-unwind-tables"
export LDFLAGS="-lpthread"
%configure --enable-libao --disable-cpucheck force_arch=i586
make

%install
install -D -m755 src/zsnes %{buildroot}%{_bindir}/%{name}
install -D -m644 src/linux/zsnes.1 %{buildroot}%{_mandir}/man1/%{name}.1
install -D -m644 src/linux/zsnes.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop

for size in 16x16 32x32 48x48; do
  install -D -m644 %{name}-${size}.png %{buildroot}%{_iconsdir}/hicolor/${size}/apps/%{name}.png
done

%files
%doc docs/*
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.png
%{_mandir}/man1/%{name}.1*


%changelog
* Thu Dec 08 2022 daviddavid <daviddavid> 1:1.51-15.mga9
+ Revision: 1919482
- compile with C++14 for now to workaround FTBFS
- Mageia 9 Mass Rebuild

* Tue Nov 03 2020 akien <akien> 1:1.51-14.mga8
+ Revision: 1642357
- Fix multiple definition FTBFS with GCC 10
- Rebuild for Mageia 8
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Mar 05 2016 akien <akien> 13.mga7-current
+ Revision: 986046
- Prevent binary stripping
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Jan 09 2015 akien <akien> 1:1.51-12.mga5
+ Revision: 809621
- Restore the custom CFLAGS to fix running with fortify

* Fri Jan 09 2015 akien <akien> 1:1.51-11.mga5
+ Revision: 809561
- Add patches synced from ROSA
  o Build with GCC 4.7+
  o Properly reset directions on joystick
  o Initialize driver_format.matrix with NULL
- Drop custom CFLAGS, it seems to build with default ones (reverted)
- Install icons to hicolor theme
- De-obsolete zsnes
+ zezinho <zezinho>
- does not build anymore, not maintained upstream
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 15 2011 fwang <fwang> 1:1.51-10.mga2
+ Revision: 144035
- add gentoo patch to fix build

* Sun May 08 2011 dmorgan <dmorgan> 1:1.51-10.mga1
+ Revision: 96160
- imported package zsnes


* Sun Mar 28 2010 Funda Wang <fwang@mandriva.org> 1:1.51-10mdv2010.1
+ Revision: 528414
- rebuild

* Mon Sep 21 2009 Thierry Vignaud <tv@mandriva.org> 1:1.51-9mdv2010.0
+ Revision: 446352
- rebuild

* Thu Mar 19 2009 Michael Scherer <misc@mandriva.org> 1:1.51-8mdv2009.1
+ Revision: 357567
- rebuild

* Sun Mar 01 2009 Emmanuel Andry <eandry@mandriva.org> 1:1.51-7mdv2009.1
+ Revision: 346250
- use autoreconf
- fix gcc43 build with P2 from gentoo

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - rebuild

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Wed Mar 12 2008 Guillaume Bedot <littletux@mandriva.org> 1:1.51-4mdv2008.1
+ Revision: 187178
- builds only for 32bit
- removed optimizations
- fix libao output (patch1)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Jun 01 2007 Michael Scherer <misc@mandriva.org> 1:1.51-3mdv2008.0
+ Revision: 33533
- use libao output, as suggested by brancaleone


* Sun Feb 11 2007 Michael Scherer <misc@mandriva.org> 1.51-2mdv2007.0
+ Revision: 118827
- use option to make it work on other arch than p4 ( ie do not optimize for cluster )

* Thu Jan 25 2007 Götz Waschk <waschk@mandriva.org> 1:1.51-1mdv2007.1
+ Revision: 113082
- new version

* Tue Dec 26 2006 Nicolas Lécureuil <neoclust@mandriva.org> 1:1.50-3mdv2007.1
+ Revision: 102078
- Remove old debian menu style

* Sat Dec 23 2006 Michael Scherer <misc@mandriva.org> 1:1.50-2mdv2007.1
+ Revision: 101952
- fix build on x86_64, with previous changes
- rebuild, to fix bug #23844 ( zsnes not working )
- do not use FORTIFY, zsnes segfault quite immediatly

* Sat Dec 23 2006 Götz Waschk <waschk@mandriva.org> 1:1.50-1mdv2007.1
+ Revision: 101900
- fix buildrequires
- build on x86_64 as well
- add menu entry
- Import zsnes

* Sat Dec 23 2006 Götz Waschk <waschk@mandriva.org> 1.50-1mdv2007.1
- new version

* Tue Apr 11 2006 Michael Scherer <misc@mandriva.org> 1:1.42-2mdk
- Rebuild
- use mkrel

* Thu Jan 20 2005 Götz Waschk <waschk@linux-mandrake.com> 1.42-1mdk
- new version

* Mon Dec 27 2004 Götz Waschk <waschk@linux-mandrake.com> 1.40-1mdk
- spec fixes
- New release 1.40

* Sun Jun 06 2004 Michael Scherer <misc@mandrake.org> 1.36-4mdk 
- rebuild
- change menu

